/****************************************************************************

 ■Software Radio
		Copyright(C) 2019 Denshi Usagi

****************************************************************************/

//#define SLAVE_DEBUG

#include "config.h"

#include <xc.h>
#include <p33CH64MP202.h>

#ifndef SLAVE_DEBUG
#include "Slave.h"
//#include "../Slave.X/dist/default/production/Slave.h"
#endif

//=================================================================

typedef	int fractional;

#define PORT_LED	_LATB5
#define PORT_AEN	_LATB10

#define PLL_DIV		90	// FOSC:180MHz 90MIPS (150MIPS位までOK?)
#define FCY			90000000 // MHz(for LIBPIC30)

#include <libpic30.h>

//=================================================================

static void InitSystem(void);
static void Run(void);

//=================================================================

// ●メインエントリ
int main(void)
{
	InitSystem();
	Run();
	return 0;
}

// ●システム初期化
static void InitSystem(void)
{
	// メインクロック設定( FOSC = (4 * M) / (N1 * N2 * N3) )
	PLLFBDbits.PLLFBDIV = PLL_DIV; // M (400～1600, Default:150 max:200)
	CLKDIVbits.PLLPRE = 1;		// N1
	PLLDIVbits.POST1DIV = 2;	// N2 (1～7, must POST1DIVx >= POST2DIVx def:4)
	PLLDIVbits.POST2DIV = 1;	// N3 (1～7, must POST1DIVx >= POST2DIVx def:1)
	
	// DAC用クロック設定：500MHz( AFPLLO = (8 * M) / (N1 * N2 * N3) )
	APLLFBD1bits.APLLFBDIV = 125; // M
	ACLKCON1bits.APLLPRE = 1;	// N1
	APLLDIV1bits.APOST1DIV = 2;	// N2 (1～7, must POST1DIVx >= POST2DIVx def:4)
	APLLDIV1bits.APOST2DIV = 1;	// N3 (1～7, must POST1DIVx >= POST2DIVx def:1)

	// ポート初期化
	PORTA = PORTB = 0x00;
	LATA = LATB = 0x00;

	// PORT_LED(RB5)
	TRISBbits.TRISB5 = 0;

	// PORT_AEN(RB10)
	PORT_AEN = 1;
	ODCBbits.ODCB10 = 1; // Open-drain is enabled 
	TRISBbits.TRISB10 = 0;

	// FIFO(Slave→Master)
	MSI1CONbits.RFITSEL = 0b01; // Trigger data valid interrupt when FIFO is 50% full after Slave write
	_MSIFLTIE = 1; // FIFO Fault Interrupt for Overflow or Underflow
	//_MSIDTIE = 1; // Master FIFO Data Ready Interrupt(※テスト用)
	
	// DAC
	DACCTRL1Lbits.CLKSEL = 0b10; // AFPLLO
	DACCTRL1Lbits.CLKDIV = 0b00; // 1x
	DAC1CONLbits.DACEN = 1; // Enables DACx module
	DAC1CONLbits.DACOEN = 1; // DACx analog voltage is connected to the DACOUT1 pin
	DAC1DATHbits.DACDATH = 0; 
	DACCTRL1Lbits.DACON = 1;  
	
	// SCCP1(FIFOエラー表示LED点滅用)
	CCP1CON1Lbits.CLKSEL = 0b000; // FOSC/2(FP)
	CCP1CON1Lbits.TMRPS = 0b00; // 1:1 Prescaler
	CCP1CON1Lbits.T32 = 1; // Uses 32-bit time base for timer
	CCP1CON1Lbits.CCSEL = 0; // Output Compare/PWM/Timer peripheral 
	CCP1CON1Lbits.MOD = 0b0000; // 16-Bit/32-Bit Timer mode
	CCP1CON1Hbits.TRIGEN = 0; // Trigger operation of time base is disabled
	CCP1CON1Hbits.SYNC = 0b00000; // None
	CCP1TMRH = 0;
	CCP1TMRL = 0;
	CCP1PRH = 0x02FA;
	CCP1PRL = 0xF080;
	_CCT1IE = 1;

	// SCCP2(サイクル計測用カウンタ ※テスト用)
	CCP2CON1Lbits.CLKSEL = 0b000; // FOSC/2(FP)
	CCP2CON1Lbits.TMRPS = 0b00; // 1:1 Prescaler
	CCP2CON1Lbits.T32 = 0; // Uses 16-bit time base for timer
	CCP2CON1Lbits.CCSEL = 0; // Output Compare/PWM/Timer peripheral 
	CCP2CON1Lbits.MOD = 0b0000; // 16-Bit/32-Bit Timer mode
	CCP2CON1Hbits.TRIGEN = 0; // Trigger operation of time base is disabled
	CCP2CON1Hbits.SYNC = 0b00000; // None
	CCP2TMRL = 0;

	// サイクル計測用カウンタON(※テスト用)
	//CCP2CON1Lbits.CCPON = 1;

	// AVDD(2.3V)安定待ち
	__delay_ms(500); // リップルフィルタ電圧上昇待ち
	
#ifndef SLAVE_DEBUG

	// Slave側を起動する
	_program_slave(1, 0, Slave);
	_start_slave();

#endif
}

// ●実行ループ
static void Run(void)
{
	PORT_LED = 1;

	// アンプ(HT82V739)PowerUp())
	PORT_AEN = 0;
	__delay_ms(250); // ポップノイズ低減

	// コア設定
	CORCONbits.IF = 1; // Integer mode is enabled for DSP multiply
	CORCONbits.US = 0b01; // DSP engine multiplies are unsigned
	CORCONbits.SATA = 0; // Accumulator A saturation is enabled
	CORCONbits.SATB = 0; // Accumulator B saturation is enabled
	CORCONbits.SATDW = 0; // Data Space write saturation is disabled

	// 受信開始
	_MSIDTIF = 0;
	MSI1FIFOCSbits.RFEN = 1;

	asm("MOV #205, w3");
	asm("MOV #DAC1DATH, w10");

	// 電源断まで無限ループ(FIFO待ち処理を除き、30サイクル)
	asm("LOOP:");
	{
		// FIFOが50%(16Byte)になるまで待つ
		asm("WAIT_FIFO:");
		asm("BTSS IFS8, #10"); // _MSIDTIF
		asm("BRA WAIT_FIFO");
		
		// FIFO MRSWFDATA から読み出す
		// x = MRSWFDATA
		asm("MOV MRSWFDATA, w4");
		// y = MRSWFDATA
		asm("MOV MRSWFDATA, w5");

		// _MSIDTIFをクリア
		asm("BCLR IFS8, #10");
		
		// x(w4) = abs(x)
		asm("BTSC w4, #15");
		asm("NEG w4, w4");

		// y(w5) = abs(y)
		asm("BTSC w5, #15");
		asm("NEG w5, w5");

		// max(w4) = (x > y)? x : y
		// min(w5) = (x > y)? y : x
		asm("CP w4, w5");
		asm("BTSS SR, #0");
		asm("EXCH w4, w5");

		// if ( 2 * max < 5 * min)
		asm("MOV #2, w6");
		asm("MPY w4 * w6, A");
		asm("MOV #5, w7");
		asm("MPY w5 * w7, B");
		asm("SUB A");
		asm("SAC A, w0");
		asm("BTSS w0, #15");
		asm("BRA NEXT1");

		// d = 864 * max + 569 * min
		asm("MOV #864, w6");
		asm("MOV #569, w7");
		asm("BRA NEXT2");

		// d = 1016 * max + 190 * min
		asm("NEXT1:");
		asm("MOV #1016, w6");
		asm("MOV #190, w7");

		asm("NEXT2:");
		asm("MPY w4 * w6, A");
		asm("MAC w5 * w7, A");
		
		// d = (d + 512) >> 10
		
		// 上の演算は行わず、-4(10-16-1-1+4)シフトする
		// ・丸め処理はコアがやってくれるため「+512」は不要
		// ・SAC命令は{#Slit4}を指定してもAcc[16:0]がシフトされないため「-16」シフトする
		// ・直交復調では信号成分が1/2になるため2倍する「-1」シフト
		// ・ADCには1/2スケールで入力しているため2倍する「-1」シフト
		// ・DACデータとして12bit化するために「+4」シフトする
		asm("SFTAC A, #-4");
		
		// DACDAT<11:0>: Valid values are from 205 to 3890.
		asm("ADD w3, A");
		
		// DACへ出力
		asm("SAC.R A, [w10]");
	}
	asm("BRA LOOP");
}

// ●FIFOオーバーフローアンダフロー割り込み
void __attribute__((interrupt, shadow, no_auto_psv)) _MSIFLTInterrupt(void)
{
	CCP1CON1Lbits.CCPON = 1;
	_MSIFLTIF = 0;
}

// ●CCP1タイマー割り込み
void __attribute__((interrupt, shadow, no_auto_psv)) _CCT1Interrupt(void)
{
	PORT_LED = !PORT_LED;
	_CCT1IF = 0;
}

// ●FIFOデータ受信割り込み(※テスト用)
void __attribute__((interrupt, shadow, no_auto_psv)) _MSIDTInterrupt(void)
{
	static int nTime[100];
	static int nData[200];
	static int i = 0, j = 0;

	if (i < 100)
	{
		nTime[i++] = CCP2TMRL; // 受信周期確認用
		nData[j++] = MRSWFDATA;
		nData[j++] = MRSWFDATA;
	}
	else
	{
		for (--i; i > 0; i--)
			nTime[i] = nTime[i] - nTime[i - 1];
		i = 0;
	}

	_MSIDTIF = 0;
}
